@@ -96,9 +96,19 @@ def thread_manager(table_name, schema, cnxn_string, thread_count, df_queue, colu
 
 
 def to_sql(df_in, table_name, cnxn_string, schema='dbo', index=True, replace=False, chunk_size=1000, thread_count=5, ignore_truncation=False, ignore_missing=False):
+    if len(df_in) == 0:
+        print("\nWarning: Attempting to upload an empty dataframe.\n"
+              "An Error will not be thrown, but the operation will be skipped.\n")
+        return
+
     # Make a copy of the data, as to not apply adjustments to the original dataframe
     df_out = df_in.copy()
 
+    if index:
+        df_out.reset_index(inplace=True)
+    else:
+        df_out.reset_index(inplace=True, drop=True)
+
     # table columns
     trimmed_name = table_name.replace('[', '').replace(']', '')
     query = f"""SELECT *,
@@ -130,7 +140,7 @@ def to_sql(df_in, table_name, cnxn_string, schema='dbo', index=True, replace=Fal
 
     # truncation will occur on character based data types
     if not ignore_truncation:
-        max_char_cols = columns[~columns['CHARACTER_MAXIMUM_LENGTH'].isnull()][['COLUMN_NAME', 'CHARACTER_MAXIMUM_LENGTH']]
+        max_char_cols = columns[(~columns['CHARACTER_MAXIMUM_LENGTH'].isnull()) & (columns['CHARACTER_MAXIMUM_LENGTH'] != -1)][['COLUMN_NAME', 'CHARACTER_MAXIMUM_LENGTH']]
         for col, max_char in zip(max_char_cols['COLUMN_NAME'], max_char_cols['CHARACTER_MAXIMUM_LENGTH']):
             if df_out[col].apply(lambda x: len(str(x)) if not pd.isnull(x) else 0).max() > max_char:
                 raise TruncationException(f"Column '{col}' contains elements that are too large for the destination table.\n"
@@ -144,11 +154,6 @@ def to_sql(df_in, table_name, cnxn_string, schema='dbo', index=True, replace=Fal
         crsr.close()
         cnxn.close()
 
-    if index:
-        df_out.reset_index(inplace=True)
-    else:
-        df_out.reset_index(inplace=True, drop=True)
-
     # stringify
     for column in df_out.columns:
         df_out[column] = df_out[column].apply(lambda x: str(x).replace("'", "''") if not pd.isnull(x) else x)
